@@ -16,7 +16,25 @@ get_last_release = function(){
   file_cache = file.path(insee_data_dir, paste0(openssl::md5(insee_last_release_link), ".rds"))
 
   if(!file.exists(file_cache)){
-    response = httr::GET(insee_last_release_link)
+    
+    option_mode = Sys.getenv("INSEE_download_option_mode")
+    option_method = Sys.getenv("INSEE_download_option_method")
+    option_port = Sys.getenv("INSEE_download_option_port")
+    option_extra = Sys.getenv("INSEE_download_option_extra")
+    option_proxy = Sys.getenv("INSEE_download_option_proxy")
+    option_auth = Sys.getenv("INSEE_download_option_auth")
+    
+    if(option_extra == ""){
+      response = httr::GET(insee_last_release_link)
+    }else{
+      
+      proxy = httr::use_proxy(url = option_proxy,
+                              port = as.numeric(option_port),
+                              auth = option_auth)
+      
+      response = httr::GET(url = insee_last_release_link,
+                           config = proxy)
+    }
 
     data_xml = xml2::read_xml(response)
     data_list = xml2::as_list(data_xml)
